@@ -164,7 +164,7 @@ static void ogrReadColumnData(OgrFdwState *state);
 /* Global to hold GEOMETRYOID */
 Oid GEOMETRYOID = InvalidOid;
 
-#if GDAL_VERSION_MAJOR >= 2 && GDAL_VERSION_MINOR >= 1
+#if GDAL_VERSION_NUM >= GDAL_COMPUTE_VERSION(2,1,0)
 static void
 ogrErrorHandler(CPLErr eErrClass, int err_no, const char *msg)
 {
@@ -204,7 +204,7 @@ _PG_init(void)
 
 	on_proc_exit(&ogr_fdw_exit, PointerGetDatum(NULL));
 
-#if GDAL_VERSION_MAJOR >= 2 && GDAL_VERSION_MINOR >= 1
+#if GDAL_VERSION_NUM >= GDAL_COMPUTE_VERSION(2,1,0)
 	/* Hook up the GDAL error handlers to PgSQL elog() */
 	CPLSetErrorHandler(ogrErrorHandler);
 	CPLSetCurrentErrorHandlerCatchDebug(true);
@@ -1099,7 +1099,7 @@ ogrReadColumnData(OgrFdwState *state)
 	/* Get OGR metadata ready */
 	dfn = OGR_L_GetLayerDefn(state->ogr.lyr);
 	ogr_ncols = OGR_FD_GetFieldCount(dfn);
-#if GDAL_VERSION_NUM >= GDAL_COMPUTE_VERSION(1,11,0)
+#if (GDAL_VERSION_NUM >= GDAL_COMPUTE_VERSION(1,11,0))
 	ogr_geom_count = OGR_FD_GetGeomFieldCount(dfn);
 #else
 	ogr_geom_count = ( OGR_FD_GetGeomType(dfn) != wkbNone ) ? 1 : 0;
@@ -1155,7 +1155,11 @@ ogrReadColumnData(OgrFdwState *state)
 		getTypeBinaryOutputInfo(col.pgtype, &col.pgsendfunc, &col.pgsendvarlena);
 
 		/* Get the PgSQL column name */
-		col.pgname = get_relid_attribute_name(rel->rd_id, att_tuple->attnum);
+#if PG_VERSION_NUM >= 110000
+		col.pgname = get_attname(rel->rd_id, att_tuple->attnum, false);
+#else
+		col.pgname = get_attname(rel->rd_id, att_tuple->attnum);
+#endif
 
 		/* Handle FID first */
 		if ( strcaseeq(col.pgname, "fid") && (col.pgtype == INT4OID || col.pgtype == INT8OID) )
@@ -1442,7 +1446,7 @@ ogrFeatureToSlot(const OGRFeatureH feat, TupleTableSlot *slot, const OgrFdwExecS
 			unsigned char *wkb;
 			OGRErr err;
 
-#if GDAL_VERSION_NUM >= GDAL_COMPUTE_VERSION(1,11,0)
+#if (GDAL_VERSION_NUM >= GDAL_COMPUTE_VERSION(1,11,0))
 			OGRGeometryH geom = OGR_F_GetGeomFieldRef(feat, ogrfldnum);
 #else
 			OGRGeometryH geom = OGR_F_GetGeometryRef(feat);
@@ -1546,7 +1550,7 @@ ogrFeatureToSlot(const OGRFeatureH feat, TupleTableSlot *slot, const OgrFdwExecS
 		}
 		else if ( ogrvariant == OGR_FIELD )
 		{
-#if GDAL_VERSION_NUM >= GDAL_COMPUTE_VERSION(2,2,0)
+#if (GDAL_VERSION_NUM >= GDAL_COMPUTE_VERSION(2,2,0))
 			int field_not_null = OGR_F_IsFieldSet(feat, ogrfldnum) && ! OGR_F_IsFieldNull(feat, ogrfldnum);
 #else
 			int field_not_null = OGR_F_IsFieldSet(feat, ogrfldnum);
@@ -1797,7 +1801,7 @@ ogrSlotToFeature(const TupleTableSlot *slot, OGRFeatureH feat, const OgrFdwTable
 			OGRErr err;
 			if ( nulls[i] )
 			{
-#if GDAL_VERSION_NUM >= GDAL_COMPUTE_VERSION(1,11,0)
+#if (GDAL_VERSION_NUM >= GDAL_COMPUTE_VERSION(1,11,0))
 				err = OGR_F_SetGeomFieldDirectly(feat, ogrfldnum, NULL);
 #else
 				err = OGR_F_SetGeometryDirectly(feat, NULL);
@@ -1818,7 +1822,7 @@ ogrSlotToFeature(const TupleTableSlot *slot, OGRFeatureH feat, const OgrFdwTable
 				if ( err != OGRERR_NONE )
 					return err;
 
-#if GDAL_VERSION_NUM >= GDAL_COMPUTE_VERSION(1,11,0)
+#if (GDAL_VERSION_NUM >= GDAL_COMPUTE_VERSION(1,11,0))
 				err = OGR_F_SetGeomFieldDirectly(feat, ogrfldnum, geom);
 #else
 				err = OGR_F_SetGeometryDirectly(feat, geom);
